@@ -38,7 +38,7 @@ try:
 except ImportError:
     _warn.warn('# matplotlib, astropy and/or scipy module not installed!!')
 
-__version__ = '1.5.2'
+__version__ = '1.5.3'
 __release__ = "Stable"
 __author__ = "Daniel Moser"
 __email__ = "dmfaes@gmail.com"
@@ -78,7 +78,7 @@ def sed2info(sfile):
     f0.close()
     info = ''
     i = 0
-    while info is '':
+    while info == '':
         if fcont[i][0] != '%':
             info = _np.array(fcont[i].split(), dtype=float)
         i += 1
